@@ -29,6 +29,11 @@ PERFORMANCE OF THIS SOFTWARE.
 #include "mysql.h"
 #include "mysqld_error.h"
 
+#if MYSQL_VERSION_ID >= 80000
+// https://github.com/mysql/mysql-server/commit/eb821c023cedc029ca0b06456dfae365106bee84
+#define my_bool _Bool
+#endif
+
 #include "Python.h"
 #if PY_MAJOR_VERSION >= 3
 #define IS_PY3K
@@ -363,12 +368,6 @@ _mysql_ResultObject_Initialize(
 	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O!|iO", kwlist,
 					 &_mysql_ConnectionObject_Type, &conn, &use, &conv))
 		return -1;
-	if (!conv) {
-		if (!(conv = PyDict_New()))
-			return -1;
-	}
-	else
-		Py_INCREF(conv);
 
 	self->conn = (PyObject *) conn;
 	Py_INCREF(conn);
@@ -387,13 +386,11 @@ _mysql_ResultObject_Initialize(
 		    return -1;
 		}
 		self->converter = PyTuple_New(0);
-		Py_DECREF(conv);
 		return 0;
 	}
 	n = mysql_num_fields(result);
 	self->nfields = n;
 	if (!(self->converter = PyTuple_New(n))) {
-		Py_DECREF(conv);
 		return -1;
 	}
 	fields = mysql_fetch_fields(result);
@@ -401,15 +398,13 @@ _mysql_ResultObject_Initialize(
 		PyObject *tmp, *fun;
 		tmp = PyInt_FromLong((long) fields[i].type);
 		if (!tmp) {
-			Py_DECREF(conv);
 			return -1;
 		}
-		fun = PyObject_GetItem(conv, tmp);
+		fun = conv ? PyObject_GetItem(conv, tmp) : NULL;
 		Py_DECREF(tmp);
 		if (!fun) {
 			if (PyErr_Occurred()) {
 				if (!PyErr_ExceptionMatches(PyExc_KeyError)) {
-					Py_DECREF(conv);
 					return -1;
 				}
 				PyErr_Clear();
@@ -428,7 +423,6 @@ _mysql_ResultObject_Initialize(
 				PyObject *t = PySequence_GetItem(fun, j);
 				if (!t) {
 					Py_DECREF(fun);
-					Py_DECREF(conv);
 					return -1;
 				}
 				if (PyTuple_Check(t) && PyTuple_GET_SIZE(t) == 2) {
@@ -463,7 +457,6 @@ _mysql_ResultObject_Initialize(
 		PyTuple_SET_ITEM(self->converter, i, fun);
 	}
 
-	Py_DECREF(conv);
 	return 0;
 }
 
@@ -1891,7 +1884,7 @@ _mysql_ConnectionObject_ping(
 	if (!PyArg_ParseTuple(args, "|I", &reconnect)) return NULL;
 	check_connection(self);
 	if (reconnect != -1) {
-		my_bool recon = reconnect;
+		my_bool recon = (my_bool)reconnect;
 		mysql_options(&self->connection, MYSQL_OPT_RECONNECT, &recon);
 	}
 	Py_BEGIN_ALLOW_THREADS
@@ -2178,46 +2171,6 @@ _mysql_ResultObject_data_seek(
 	return Py_None;
 }
 
-static char _mysql_ResultObject_row_seek__doc__[] =
-"row_seek(n) -- seek by offset n rows of result set";
-static PyObject *
-_mysql_ResultObject_row_seek(
-     _mysql_ResultObject *self,
-     PyObject *args)
-{
-	int offset;
-        MYSQL_ROW_OFFSET r;
-	if (!PyArg_ParseTuple(args, "i:row_seek", &offset)) return NULL;
-	check_result_connection(self);
-	if (self->use) {
-		PyErr_SetString(_mysql_ProgrammingError,
-				"cannot be used with connection.use_result()");
-		return NULL;
-	}
-	r = mysql_row_tell(self->result);
-	mysql_row_seek(self->result, r+offset);
-	Py_INCREF(Py_None);
-	return Py_None;
-}
-
-static char _mysql_ResultObject_row_tell__doc__[] =
-"row_tell() -- return the current row number of the result set.";
-static PyObject *
-_mysql_ResultObject_row_tell(
-	_mysql_ResultObject *self,
-	PyObject *noargs)
-{
-	MYSQL_ROW_OFFSET r;
-	check_result_connection(self);
-	if (self->use) {
-		PyErr_SetString(_mysql_ProgrammingError,
-				"cannot be used with connection.use_result()");
-		return NULL;
-	}
-	r = mysql_row_tell(self->result);
-	return PyInt_FromLong(r-self->result->data->data);
-}
-
 static void
 _mysql_ResultObject_dealloc(
 	_mysql_ResultObject *self)
@@ -2516,18 +2469,6 @@ static PyMethodDef _mysql_ResultObject_methods[] = {
 		METH_VARARGS,
 		_mysql_ResultObject_data_seek__doc__
 	},
-	{
-		"row_seek",
-		(PyCFunction)_mysql_ResultObject_row_seek,
-		METH_VARARGS,
-		_mysql_ResultObject_row_seek__doc__
-	},
-	{
-		"row_tell",
-		(PyCFunction)_mysql_ResultObject_row_tell,
-		METH_NOARGS,
-		_mysql_ResultObject_row_tell__doc__
-	},
 	{
 		"describe",
 		(PyCFunction)_mysql_ResultObject_describe,
